@@ -311,7 +311,7 @@ class DynamoFL(_Base):
         ext = project_info['modelType']
         current_round = project_info['currentRound']
         prev_round = self._get_last_fed_model_round(current_round, project_info['isComplete'])
-        federated_model_path = get_federated_path(model_path, ext, datasource_key, prev_round)
+        federated_model_path = get_federated_path(project_key, model_path, ext, datasource_key, prev_round)
 
         yes_stats = len(self._check_stats(project_info['key'], datasource_key, prev_round))
         yes_submission = len(self._check_submissions(project_info['key'], datasource_key, current_round))
@@ -335,7 +335,7 @@ class DynamoFL(_Base):
 
         # Train and push
         if not yes_submission:
-            new_model_path = get_trained_path(model_path, ext, datasource_key, current_round)
+            new_model_path = get_trained_path(project_key, model_path, ext, datasource_key, current_round)
 
             print(f'>>> ({project_key}-{datasource_key}) Training weights on local model...')
             train(datasource_key, federated_model_path, new_model_path, project_info, hyper_param_values)
@@ -418,10 +418,10 @@ class DynamoFL(_Base):
         return self._make_request('GET', f'/projects/{project_key}/stats', params, list=True)
 
 
-def get_trained_path(base, ext, ds, round):
-    return f'{base}/trained_model_{ds}_{round}.{ext}'
-def get_federated_path(base, ext, ds, round):
-    return f'{base}/federated_model_{ds}_{round}.{ext}'
+def get_trained_path(project_key, base, ext, ds, round):
+    return f'{base}/trained_model_{project_key}_{ds}_{round}.{ext}'
+def get_federated_path(project_key, base, ext, ds, round):
+    return f'{base}/federated_model_{project_key}_{ds}_{round}.{ext}'
 
 
 def get_threads_key(project_key, datasource_key):
